@@ -247,7 +247,7 @@ def process_orcaflex(job: QalxJob) -> None:
             update_job_state({"state": "Uploading simulation"})
             sim_name = f"{job.entity['meta']['case_name']}.sim"
             job.entity["items"]["simulation_file"] = job.session.item.add(
-                input_file=BytesIO(model_bytes),
+                source=BytesIO(model_bytes),
                 file_name=sim_name,
                 meta={"_class": "orcaflex.simulation_file"},
             )
@@ -392,7 +392,7 @@ def process_orcaflex(job: QalxJob) -> None:
                 viewParameters=vp
             )  # bytes of saved view
             mvi = job.session.item.add(
-                input_file=BytesIO(save_bytes),
+                source=BytesIO(save_bytes),
                 file_name=mv.view_filename,
                 meta={"_class": "orcaflex.saved_view"},
             )  # save to qalx
@@ -475,7 +475,15 @@ def process_orcaflex(job: QalxJob) -> None:
         update_job_warnings([msg])
         update_job_state({"state": "Simulation unstable"})
 
-    job.add_step_result(
-        result_data={"model": model}
-    )  # this allows `postprocessing_function` to access model data
+    # this allows `postprocessing_function` to access model data
+    job.context["model"] = model
     job.entity["meta"]["processing_complete"] = True  # we done.
+
+
+def post_process_orcaflex(job: QalxJob):
+    send_to = job.entity["meta"].get("send_to", [])
+    if send_to:
+        for queue_name in send_to:
+            queue = job.session.queue.get_or_create(queue_name)
+            job.entity.__class__.add_to_queue(payload=job.entity, queue=queue)
+            job.log.debug(f"{job.entity.guid} sent to {queue_name}")
