@@ -8,7 +8,7 @@ from typing import Union, Sequence, Mapping
 
 import pyqalx
 from OrcFxAPI import Model
-from pyqalx import QalxSession, Item
+from pyqalx import QalxSession, Item, Group
 
 from qalx_orcaflex import data_models
 from qalx_orcaflex.helpers import (
@@ -89,13 +89,13 @@ class ModelSource(BaseSource):
         :param name: the name of the model, used as the file name to save back later.
         """
         super(ModelSource, self).__init__(model, name)
-        self.model_byes = model.SaveDataMem()
+        self.model_bytes = model.SaveDataMem()
         self.name = name
         self._clean_name = clean_set_key(name)
 
     def to_jobs(self, base_job: Mapping) -> Mapping:
         data_file = {
-            "input_file": BytesIO(self.model_byes),
+            "source": BytesIO(self.model_bytes),
             "meta": {
                 "_class": "orcaflex.job.data_file",
                 "data_file_name": f"{self.name}.dat",
@@ -118,7 +118,7 @@ class FileSource(BaseSource):
         self.path = path
 
     def to_jobs(self, base_job: Mapping) -> Mapping:
-        data_file = {"input_file": self.path, "meta": {}}
+        data_file = {"source": self.path, "meta": {}}
         dfp = self._path_meta(data_file, self.path)
         job = self._update_copy(
             base_job, {"data_file": data_file, "case_name": dfp.stem}
@@ -154,7 +154,7 @@ class DirectorySource(BaseSource):
             self.directory, self.include_yaml, self.skip_fails, self.recursive
         ):
             data_file = {
-                "input_file": str(dfp),
+                "source": str(dfp),
                 "meta": {"_class": "orcaflex.job.data_file"},
             }
             self._path_meta(data_file, dfp)
@@ -240,12 +240,6 @@ class OrcaFlexBatch:
         self.name = name
         self.session = session
         self.batch_options = batch_options
-        if self.batch_options.summarise_results and (
-            not self.batch_options.wait_to_complete
-        ):
-            raise QalxOrcaFlexError(
-                "summarise results must be set with the wait_to_complete option."
-            )
         self.dry_run = dry_run
         standard_meta = {
             "_class": "orcaflex.batch",
@@ -284,6 +278,7 @@ class OrcaFlexBatch:
                 "_class": "orcaflex.job",
                 "case_name": case_name,
                 "state": asdict(data_models.OrcaFlexJobState()),
+                "send_to": self.batch_options.send_sim_to,
             },
         )
 
@@ -384,7 +379,7 @@ class OrcaFlexBatch:
         if self.verbose:  # print
             print(f"added {case_name}")
         self.session.log.info(f"created {case_name}")
-        self.built_sets[case_name].items = job_items_zipped  # put items on the set
+        self.built_sets[case_name]["items"] = job_items_zipped  # put items on the set
         self.session.set.save(
             self.built_sets[case_name]
         )  # save the set now it has the items
@@ -433,7 +428,8 @@ class OrcaFlexBatch:
         batch_queue = self.session.queue.get_or_create(
             self.batch_options.batch_queue
         )  # do batch queue
-        batch_queue.submit_entity(self.group_batch)  # submit batch
+        # submit batch
+        Group.add_to_queue(payload=self.group_batch, queue=batch_queue)
 
     def __enter__(self):
         self.batch_manager = OrcaFlexBatchManager()
