@@ -17,7 +17,7 @@ processing of the simulation.
 """
 import ctypes as ct
 from dataclasses import dataclass, field, asdict
-from typing import List, Mapping, Any, Tuple
+from typing import List, Mapping, Any, Tuple, Sequence
 
 import OrcFxAPI
 from pyqalx.core.entities import Item
@@ -82,21 +82,22 @@ class BatchOptions:
 
     :param batch_queue[str]: name of the batch queue
     :param sim_queue[str]: name of the simulation queue
-    :param wait_to_complete[bool]: should the batch bot wait for a batch to complete
-        (default=True)
     :param wait_between_completion_checks[int]: how long to wait before checking for
         completion (default=30)
     :param summarise_results[bool]: should we create a results summary automatically
         (default=True)
     :param build_threads[int]: threads to use to build the batch(default=50)
+    :param send_sim_to [list]: queues to send sims to when ``SimBot`` is finished
+    :param send_batch_to [list]: queues to send batches to when ``BatchBot`` is finished
     """
 
     batch_queue: str
     sim_queue: str
-    wait_to_complete: bool = True
     wait_between_completion_checks: int = 30
     summarise_results: bool = True
     build_threads: int = 50
+    send_sim_to: Sequence = field(default_factory=lambda: [])
+    send_batch_to: Sequence = field(default_factory=lambda: [])
 
 
 class ValidationError(Exception):
